@@ -216,6 +216,8 @@ PYBIND11_MODULE(lsdtt_xtensor_python, m)
       .def("first_order_m_chi_from_custarray", &LSDTribBas::first_order_m_chi_from_custarray)
 
       ; // end of class LSDTribBas
+
+    #ifdef __linux__  
     py::class_<muddpyle>(m, "muddpyle_cpp")
       .def(py::init<>())
       .def(py::init([](int nrows, int ncols, float xmin, float ymin, float cellsize, float ndv, xt::pytensor<float,2>& initial_topography, float m, float n, int dt, int Umod, float save_step, float default_D, float default_Sc, xt::pytensor<float,2>& K_field, xt::pytensor<float,2>& U_field, bool hillslope_diffusion, bool use_adaptive_timestep, float max_dt, std::string OUT_DIR, std::string OUTID, std::vector<std::string> bc ){return std::unique_ptr<muddpyle>(new muddpyle( nrows,  ncols,  xmin,  ymin,  cellsize,  ndv,  initial_topography, m,  n,  dt,  Umod,  save_step,  default_D,  default_Sc,  K_field,  U_field,  hillslope_diffusion, use_adaptive_timestep,  max_dt,  OUT_DIR,  OUTID, bc)); }))
@@ -237,8 +239,8 @@ PYBIND11_MODULE(lsdtt_xtensor_python, m)
       .def("set_fluvial_erosion",&muddpyle::set_fluvial_erosion)
       .def("set_boundary_conditions",&muddpyle::set_boundary_conditions)
       .def("run_model",&muddpyle::run_model)      
-
     ;
+    #endif
 
     py::class_<LSDDEM_xtensor>(m, "LSDDEM_cpp")
       .def(py::init<>())
@@ -274,6 +276,7 @@ PYBIND11_MODULE(lsdtt_xtensor_python, m)
       .def("get_channel_gradient_muddetal2014", &LSDDEM_xtensor::get_channel_gradient_muddetal2014)
       .def("get_ksn_first_order_chi", &LSDDEM_xtensor::get_ksn_first_order_chi)
       .def("ingest_channel_head", &LSDDEM_xtensor::ingest_channel_head)
+      .def("get_DA_raster", &LSDDEM_xtensor::get_DA_raster)
 
       ;// end of class LSDDEM (semicolon important)
 }
